/// <reference types="@cloudflare/workers-types" />
import { ApplicationCommandType } from "discord-api-types/v10";
import type ContextMenu from "./commands/context-menu.js";
import type SlashCommand from "./commands/slash-command.js";
import type { ExecutableComponent } from "./components/index.js";
import type { MapValue, SerializableComponent } from "./interfaces.js";
type ApplicationArgs = {
    applicationId: string;
    publicKey: string;
    token: string;
    platform: SubtleCryptoImportKeyAlgorithm | string;
};
type CommandMap = {
    [ApplicationCommandType.ChatInput]: Map<string, SlashCommand>;
    [ApplicationCommandType.Message]: Map<string, ContextMenu<ApplicationCommandType.Message>>;
    [ApplicationCommandType.User]: Map<string, ContextMenu<ApplicationCommandType.User>>;
};
type CommandMapValue<K extends keyof CommandMap> = MapValue<CommandMap[K]>;
export type AllCommands = SlashCommand | ContextMenu<ApplicationCommandType.User> | ContextMenu<ApplicationCommandType.Message>;
export default class Application {
    #private;
    constructor({ applicationId, publicKey, token, platform }: ApplicationArgs);
    get id(): `${bigint}`;
    get commands(): (SlashCommand | ContextMenu<ApplicationCommandType.User> | ContextMenu<ApplicationCommandType.Message>)[];
    addCommand(command: AllCommands): this;
    addCommands(...commands: AllCommands[]): this;
    getCommand<T extends ApplicationCommandType>(type: T, name: string): CommandMapValue<T> | undefined;
    addComponent(component: SerializableComponent): this;
    getComponent(customId: string): ExecutableComponent | undefined;
    findComponent(customId: string): Promise<ExecutableComponent | undefined>;
    handler(request: Request): Promise<Response>;
    shutdown(): void;
}
export {};
